@@ -112,15 +112,6 @@ class A1_41(MessageGas, ProcessDeadline):
         else:
             return False
 
-    @property
-    def cups(self):
-        tree = '{0}.cups'.format(self._header)
-        data = get_rec_attr(self.obj, tree, False)
-        if data is not None and data is not False:
-            return data.text
-        else:
-            return False
-
     @property
     def updatereason(self):
         tree = '{0}.updatereason'.format(self._header)
